@@ -37,6 +37,8 @@ plotBranchbyTrait<-function(tree,x,mode=c("edges","tips","nodes"),palette="rainb
 	else srt<-0
 	if(hasArg(no.margin)) no.margin<-list(...)$no.margin
 	else no.margin<-TRUE
+	if(hasArg(root.edge)) root.edge<-list(...)$root.edge
+	else root.edge<-FALSE
 	if(hasArg(label.offset)) label.offset<-list(...)$label.offset
 	else label.offset<-0.01*max(nodeHeights(tree))
 	if(hasArg(underscore)) underscore<-list(...)$underscore
@@ -103,6 +105,8 @@ add.color.bar<-function(leg,cols,title=NULL,lims=c(0,1),digits=1,prompt=TRUE,...
 	}
 	if(hasArg(fsize)) fsize<-list(...)$fsize
 	else fsize<-1.0
+	if(hasArg(subtitle)) subtitle<-list(...)$subtitle
+	else subtitle<-NULL
 	X<-x+cbind(0:(length(cols)-1)/length(cols),1:length(cols)/length(cols))*(leg)
 	Y<-cbind(rep(y,length(cols)),rep(y,length(cols))) 		
 	lines(c(X[1,1],X[nrow(X),2]),c(Y[1,1],Y[nrow(Y),2]),lwd=4+2,lend=2) 
@@ -111,5 +115,6 @@ add.color.bar<-function(leg,cols,title=NULL,lims=c(0,1),digits=1,prompt=TRUE,...
 	text(x=x+leg,y=y,round(lims[2],digits),pos=3,cex=fsize)
 	if(is.null(title)) title<-"P(state=1)"
 	text(x=(2*x+leg)/2,y=y,title,pos=3,cex=fsize)
-	text(x=(2*x+leg)/2,y=y,paste("length=",round(leg,3),sep=""),pos=1,cex=fsize)
+	if(is.null(subtitle)) text(x=(2*x+leg)/2,y=y,paste("length=",round(leg,3),sep=""),pos=1,cex=fsize)
+	else text(x=(2*x+leg)/2,y=y,subtitle,pos=1,cex=fsize)
 }
