@@ -174,6 +174,8 @@ plotFan<-function(tree,colors,fsize,ftype,lwd,mar,add,part){
 # adds legend to an open stochastic map style plot
 # written by Liam J. Revell 2013
 add.simmap.legend<-function(leg=NULL,colors,prompt=TRUE,vertical=TRUE,...){
+	if(hasArg(shape)) shape<-list(...)$shape
+	else shape<-"square"
 	if(prompt){
 		cat("Click where you want to draw the legend\n")
 		x<-unlist(locator(1))
@@ -192,15 +194,16 @@ add.simmap.legend<-function(leg=NULL,colors,prompt=TRUE,vertical=TRUE,...){
 	w<-h*(par()$usr[2]-par()$usr[1])/(par()$usr[4]-par()$usr[3])
 	if(vertical){
 		y<-y-0:(length(leg)-1)*1.5*h
-		x<-rep(x+w/2,length(y))
-		symbols(x,y,squares=rep(w,length(x)),bg=colors,add=TRUE,inches=FALSE)		
+		x<-rep(x+w/2,length(y))		
 		text(x+w,y,leg,pos=4,cex=fsize)
 	} else {
 		sp<-fsize*max(strwidth(leg))
 		x<-x-w/2+0:(length(leg)-1)*1.5*(sp+w)
 		y<-rep(y+w/2,length(x))
-		symbols(x,y,squares=rep(w,length(x)),bg=colors,add=TRUE,inches=FALSE)
 		text(x,y,leg,pos=4,cex=fsize)
 	}
+	if(shape=="square") symbols(x,y,squares=rep(w,length(x)),bg=colors,add=TRUE,inches=FALSE)
+	else if(shape=="circle") symbols(x,y,circles=rep(w,length(x)),bg=colors,add=TRUE,inches=FALSE)
+	else stop(paste("shape=\"",shape,"\" is not a recognized option.",sep=""))
 }
 
